@@ -1,5 +1,6 @@
 package Test::RDF;
 
+use 5.006;
 use warnings;
 use strict;
 
@@ -11,7 +12,7 @@ use RDF::Trine::Graph;
 use Scalar::Util qw/blessed/;
 
 use base 'Test::Builder::Module';
-our @EXPORT = qw/are_subgraphs is_rdf is_valid_rdf isomorph_graphs has_subject has_predicate has_object_uri has_uri hasnt_uri has_literal hasnt_literal pattern_target pattern_ok pattern_fail/;
+our @EXPORT = qw/are_subgraphs is_rdf is_valid_rdf isomorph_graphs has_subject has_predicate has_object_uri has_type has_uri hasnt_uri has_literal hasnt_literal pattern_target pattern_ok pattern_fail/;
 
 
 =head1 NAME
@@ -20,11 +21,11 @@ Test::RDF - Test RDF data for content, validity and equality, etc.
 
 =head1 VERSION
 
-Version 1.19
+Version 1.22
 
 =cut
 
-our $VERSION = '1.19';
+our $VERSION = '1.22';
 
 
 =head1 SYNOPSIS
@@ -40,6 +41,7 @@ our $VERSION = '1.19';
  has_subject($uri_string, $model, 'Subject URI is found');
  has_predicate($uri_string, $model, 'Predicate URI is found');
  has_object_uri($uri_string, $model, 'Object URI is found');
+ has_type($uri_string, $model, 'Class URI is found');
  has_literal($string, $language, $datatype, $model, 'Literal is found');
  hasnt_literal($string, $language, $datatype, $model, 'Literal is not found');
  pattern_target($model);
@@ -225,6 +227,26 @@ sub has_object_uri {
   return _single_uri_tests($count, $name);
 }
 
+
+=head2 has_type
+
+Check if the string URI passed as first argument is an RDF class
+instance in any of the statements given in the model given as second
+argument.
+
+=cut
+
+sub has_type {
+  my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
+  my $resource = _resource_uri_checked($uri, $name);
+  return $resource unless ($resource);
+  my $count = $model->count_statements(undef,
+													RDF::Trine::Node::Resource->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#type'),
+													$resource);
+  return _single_uri_tests($count, $name);
+}
+
 =head2 has_literal
 
 Check if the string passed as first argument, with corresponding
@@ -591,7 +613,7 @@ Toby Inkster has submitted the pattern_* functions.
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2010 ABC Startsiden AS.
-Copyright 2010, 2011, 2012, 2013, 2014 Kjetil Kjernsmo.
+Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2017 Kjetil Kjernsmo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
